@@ -48,3 +48,18 @@ class TestUtils(unittest.TestCase):
 
         utils.clean(combined)
         self.assertEqual(combined.keys(), pre_clean_keys)
+
+    def test_bytes(self):
+        if six.PY3:
+            item = bytes(10)
+        else:
+            item = bytearray(10)
+
+        utils.clean(item)
+
+    def test_clean_fn(self):
+        cleaned = utils.clean({ 'fn': lambda x: x, 'number': 4 })
+        self.assertEqual(cleaned['number'], 4)
+        # TODO: fixme, different behavior on python 2 and 3
+        if 'fn' in cleaned:
+            self.assertEqual(cleaned['fn'], None)
